# Stage: Reconstruction

The purpose of this stage is to apply an assumed detector resolution to the incoming flux to convert the events' "true" energies and directions into the "reconstructed" ones.
